from typing import List

from core.position.Position import Position


class PositionSupplier:

    def get_positions(self) -> List[Position]:
        pass
